'use strict';
var self = Adapter;
module.exports = self;
const async = require('async');
const util = require("util");
const { ConfigFactory } = require("@jfrog-pipelines/configuration");
const { TRACE_ID_HEADER, ThreadLocal } = require("@jfrog/nodejs-commons");
const parseJsonBody = require('./parseJsonBody');
function Adapter(jFrogPipelinesSessionId, token) {
    logger.debug(util.format('Initializing %s', self.name));
    this.token = token;
    this.baseUrl = ConfigFactory.config.apiUrl;
    this.headers = {
        'Content-Type': 'application/json; charset=utf-8',
        'Authorization': 'apiToken '.concat(token),
        'jfrog-pipelines-session-id': jFrogPipelinesSessionId,
        [TRACE_ID_HEADER]: ThreadLocal.traceId
    };
    this.headers['user-agent'] = 'JFrog-jfpas';
    this.jFrogPipelinesSessionId = jFrogPipelinesSessionId;
}
Adapter.prototype.getTestReports =
    function (stepletId, callback) {
        this.get(util.format('/steplets/%s/testReport', stepletId), callback);
    };
function _performCall(bag, next) {
    var who = bag.who + '|' + _performCall.name;
    logger.trace(who, 'Inside');
    bag.startedAt = Date.now();
    bag.timeoutLength = 1;
    bag.timeoutLimit = 180;
    __attempt(bag, next);
    function __attempt(bag, callback) {
        request(bag.opts, function (err, res, body) {
            var interval = Date.now() - bag.startedAt;
            var connectionError = false;
            if (res) {
                logger.trace(util.format('%s took %s & returned status %s', bag.who, interval, res.statusCode));
            }
            else {
                connectionError = true;
            }
            let errorCode = 'connectionError';
            let retryLimitExceeded = false;
            const exceedRetryLimit = global.msName === 'hookHandler';
            if (typeof res !== 'undefined') {
                errorCode = res.statusCode;
            }
            if ((res && res.statusCode > 299) || err) {
                err = err || res.statusCode;
                const isInvalidRequest = isInvalidRouterRequest(body);
                if ((res && (isInvalidRequest || res.statusCode >= 500)) || connectionError) {
                    bag.timeoutLength *= 2;
                    if (bag.timeoutLength > bag.timeoutLimit) {
                        bag.timeoutLength = 1;
                        retryLimitExceeded = true;
                    }
                    if (exceedRetryLimit && retryLimitExceeded && connectionError) {
                        logger.error(`${bag.who} Retry limit exceeded for the error ${errorCode}`);
                        bag.err = err;
                    }
                    else {
                        logger.error(`${bag.who} returned error, status ${errorCode}. ` +
                            `Retrying in ${bag.timeoutLength} seconds`);
                        setTimeout(function () {
                            __attempt(bag, callback);
                        }, bag.timeoutLength * 1000);
                        return;
                    }
                }
                else {
                    if (errorCode === 409 && bag?.opts?.url.includes('/locks') &&
                        bag?.opts?.method.includes('POST')) {
                        logger.debug(util.format('%s returned status %s with error %s', bag.who, errorCode, err));
                    }
                    else {
                        logger.warn(util.format('%s returned status %s with error %s', bag.who, errorCode, err));
                    }
                    bag.err = err;
                }
            }
            bag.res = res;
            bag.body = body;
            callback();
        });
    }
}
function _parseBody(bag, next) {
    var who = bag.who + '|' + _parseBody.name;
    logger.trace(who, 'Inside');
    if (bag.body) {
        if ((bag?.res?.headers['content-type']?.startsWith('text/plain'))
            || typeof bag.body === 'object') {
            bag.parsedBody = bag.body;
        }
        else {
            bag.parsedBody = parseJsonBody(bag);
        }
    }
    return next();
}
function isInvalidRouterRequest(body) {
    if (typeof body === 'string' && body.startsWith('404 page not found')) {
        return true;
    }
    return false;
}
Adapter.prototype.get =
    function (relativeUrl, callback) {
        var bag = {};
        bag.opts = {
            method: 'GET',
            url: this.baseUrl.concat(relativeUrl),
            headers: this.headers,
            timeout: 180000
        };
        bag.who = util.format('%s call to %s for jFrogPipelinesSessionId %s', bag.opts.method, bag.opts.url, this.jFrogPipelinesSessionId);
        logger.trace(util.format('Starting %s', bag.who));
        async.series([
            _performCall.bind(null, bag),
            _parseBody.bind(null, bag)
        ], function () {
            callback(bag.err, bag.parsedBody, bag.res);
        });
    };
//# sourceMappingURL=Adapter.js.map