"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const microservice_1 = require("@jfrog-pipelines/microservice");
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const logger_1 = require("@jfrog-pipelines/logger");
const worker_1 = require("./worker");
global.request = require('request');
const logLevel = 'info';
const QUEUE_NAME = 'core.analyticsService';
const KEEP_ALIVE = {
    TIMEOUT_SEC: 60,
    MAX_CONNECTIONS: 5000
};
const store = microservice_1.applicationContext;
const serviceEnum = 15;
const options = {
    enum: serviceEnum,
    isAccessEnabled: true,
    initializers: [new microservice_1.ApiCheckInitializer(serviceEnum), new microservice_1.AmqpClientInitializer()],
    healthChecks: [],
    logLevel: logLevel,
    models: [data_access_layer_1.Step, data_access_layer_1.Steplet, data_access_layer_1.Run, data_access_layer_1.Pipeline, data_access_layer_1.Project],
    validator: new microservice_1.DefaultApplicationValidator([], [])
};
async function startApp() {
    const app = new microservice_1.Application(options, store);
    const worker = new worker_1.AnalyticsServiceWorker();
    global.logger = logger_1.LoggerFactory.getLogger('AnalyticsServiceWorker');
    global.request = global.request.defaults({
        headers: {
            Connection: 'keep-alive',
            'Keep-Alive': `timeout=${KEEP_ALIVE.TIMEOUT_SEC}, max=${KEEP_ALIVE.MAX_CONNECTIONS}`
        }
    });
    await app.listen(QUEUE_NAME, worker);
}
startApp();
//# sourceMappingURL=app.js.map